# Changelog

## [0.2.1] - 2023-03-11

- fixed: exclude .pyc files from package [vincentsarago]
- changed: updated documentation

## [0.2.0] - 2020-02-21

- added: support for binary WKBs [lovasoa]
- fixed: bug handling little-endian WKBs [lovasoa]
- removed: dependency on nose for testing

## [0.1.0] - 2018-02-14
## [0.0.3] - 2018-01-21
## [0.0.2] - 2017-08-06
## [0.0.1] - 2017-07-30

[0.2.0]: https://github.com/bosth/plpygis/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/bosth/plpygis/compare/v0.0.3...v0.1.0
[0.0.3]: https://github.com/bosth/plpygis/compare/v0.0.2...v0.0.3
[0.0.2]: https://github.com/bosth/plpygis/compare/v0.0.1...v0.0.2
[0.0.1]: https://github.com/bosth/plpygis/releases/tag/v0.0.1
